mp_create_ctbl_home_id: mp_create_ctbl_home_id

Description Usage Value

Description

map operation: create client side tbl tb0 and tb1 for home_id impersonated

Usage

1

Value

tb0: current route to home include stops at accepted packages tb1: potential route to home include one additional stops at each received request


gyang274/route documentation built on May 17, 2019, 9:41 a.m.