map operation: create client side tbl tb0 and tb1 for home_id impersonated
1 | mp_create_ctbl_home_id(home_id)
|
tb0: current route to home include stops at accepted packages tb1: potential route to home include one additional stops at each received request
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.